.. nitrate documentation master file, created by
   sphinx-quickstart on Tue Nov 26 22:58:55 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Nitrate documentation
=====================
.. TODO
   Short Description

Contents
--------

.. toctree::
   :maxdepth: 2

   about
   set_dev_env
   set_dev_env_with_vagrant
   install/index
   configuration
   guide
   contribution
   bug_reporting
   api
   releases/index
   contact
   authors
   license

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
